"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ...models.components import client as components_client
from ...models.components import clientdata as components_clientdata
from dataclasses_json import Undefined, dataclass_json
from formancesdkauth import utils


@dataclasses.dataclass
class ClientsUpdateRequest:
    id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'id', 'style': 'simple', 'explode': False }})
    client_data: components_clientdata.ClientData = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ClientsUpdateResponseBody:
    r"""The request has succeeded."""
    data: components_client.Client = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    

