"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from typing import Final


@dataclasses.dataclass
class SchemeFormanceOAuth:
    client_id: str = dataclasses.field(metadata={'security': { 'field_name': 'clientID' }})
    client_secret: str = dataclasses.field(metadata={'security': { 'field_name': 'clientSecret' }})
    TOKEN_URL: Final[str] = dataclasses.field(default='/api/auth/oauth/token')
    

